{
    "$graph": [
        {
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "class": "ExpressionTool",
            "inputs": [
                {
                    "id": "#emit_json.cwl/float_keys",
                    "type": {
                        "type": "array",
                        "items": "string"
                    }
                },
                {
                    "id": "#emit_json.cwl/float_values",
                    "type": {
                        "type": "array",
                        "items": "float"
                    }
                },
                {
                    "id": "#emit_json.cwl/long_keys",
                    "type": {
                        "type": "array",
                        "items": "string"
                    }
                },
                {
                    "id": "#emit_json.cwl/long_values",
                    "type": {
                        "type": "array",
                        "items": "long"
                    }
                },
                {
                    "id": "#emit_json.cwl/string_keys",
                    "type": {
                        "type": "array",
                        "items": "string"
                    }
                },
                {
                    "id": "#emit_json.cwl/string_values",
                    "type": {
                        "type": "array",
                        "items": "string"
                    }
                }
            ],
            "expression": "${\n\n  var OutputObject = {};\n  for (var i = 0; i < inputs.string_keys.length; i++) {\n    var key = inputs.string_keys[i];\n    var value = inputs.string_values[i];\n    OutputObject[key] = value;\n  }\n\n  for (var i = 0; i < inputs.long_keys.length; i++) {\n    var key = inputs.long_keys[i];\n    var value = parseInt(inputs.long_values[i]);\n    OutputObject[key] = value;\n  }\n\n  for (var i = 0; i < inputs.float_keys.length; i++) {\n    var key = inputs.float_keys[i];\n    var value = parseFloat(inputs.float_values[i]);\n    OutputObject[key] = value;\n  }\n\n  return {'output': JSON.stringify(OutputObject)}\n  //return {'output': OutputObject}\n}\n",
            "id": "#emit_json.cwl",
            "outputs": [
                {
                    "id": "#emit_json.cwl/output",
                    "type": "string"
                }
            ]
        },
        {
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/json-to-sqlite:31ff9a121cb13085eff7b7fb85db8b461f05b18bee1eb1b7586030dcbde8dc85"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 1000,
                    "ramMax": 1000,
                    "tmpdirMin": 10,
                    "tmpdirMax": 10,
                    "outdirMin": 10,
                    "outdirMax": 10
                }
            ],
            "class": "CommandLineTool",
            "inputs": [
                {
                    "id": "#json_to_sqlite.cwl/input_json",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--input_json"
                    }
                },
                {
                    "id": "#json_to_sqlite.cwl/job_uuid",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--job_uuid"
                    }
                },
                {
                    "id": "#json_to_sqlite.cwl/table_name",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--table_name"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#json_to_sqlite.cwl/sqlite",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid).db"
                    }
                },
                {
                    "id": "#json_to_sqlite.cwl/log",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid).log"
                    }
                }
            ],
            "baseCommand": [
                "json_to_sqlite"
            ],
            "id": "#json_to_sqlite.cwl"
        },
        {
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/sqlite_to_postgres:6ac493aa9b27dbb3fd4cbb4912e6e62a535f5692e510f0212fbddc53c2d1cc56"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 1000,
                    "ramMax": 1000,
                    "tmpdirMin": 1,
                    "tmpdirMax": 1,
                    "outdirMin": 1,
                    "outdirMax": 1
                }
            ],
            "class": "CommandLineTool",
            "inputs": [
                {
                    "id": "#sqlite_to_postgres_hirate.cwl/ini_section",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ini_section"
                    }
                },
                {
                    "id": "#sqlite_to_postgres_hirate.cwl/postgres_creds_path",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--postgres_creds_path"
                    }
                },
                {
                    "id": "#sqlite_to_postgres_hirate.cwl/source_sqlite_path",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--source_sqlite_path"
                    }
                },
                {
                    "id": "#sqlite_to_postgres_hirate.cwl/job_uuid",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--job_uuid"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#sqlite_to_postgres_hirate.cwl/log",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + \".log\")"
                    }
                }
            ],
            "baseCommand": [
                "sqlite_to_postgres"
            ],
            "id": "#sqlite_to_postgres_hirate.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/cwl_workflow_git_hash",
                    "type": "string"
                },
                {
                    "id": "#main/cwl_workflow_git_repo",
                    "type": "string"
                },
                {
                    "id": "#main/cwl_workflow_rel_path",
                    "type": "string"
                },
                {
                    "id": "#main/cwl_job_git_hash",
                    "type": "string"
                },
                {
                    "id": "#main/cwl_job_git_repo",
                    "type": "string"
                },
                {
                    "id": "#main/cwl_job_rel_path",
                    "type": "string"
                },
                {
                    "id": "#main/db_cred",
                    "type": "File"
                },
                {
                    "id": "#main/db_cred_section",
                    "type": "string"
                },
                {
                    "id": "#main/hostname",
                    "type": "string"
                },
                {
                    "id": "#main/host_ipaddress",
                    "type": "string"
                },
                {
                    "id": "#main/host_macaddress",
                    "type": "string"
                },
                {
                    "id": "#main/indexd_sqlite_uuid",
                    "type": "string"
                },
                {
                    "id": "#main/input_bam_gdc_id",
                    "type": "string"
                },
                {
                    "id": "#main/input_bam_file_size",
                    "type": "long"
                },
                {
                    "id": "#main/input_bam_md5sum",
                    "type": "string"
                },
                {
                    "id": "#main/job_uuid",
                    "type": "string"
                },
                {
                    "id": "#main/slurm_resource_cores",
                    "type": "long"
                },
                {
                    "id": "#main/slurm_resource_disk_gigabytes",
                    "type": "long"
                },
                {
                    "id": "#main/slurm_resource_mem_megabytes",
                    "type": "long"
                },
                {
                    "id": "#main/status",
                    "type": "string"
                },
                {
                    "id": "#main/status_table",
                    "type": "string"
                },
                {
                    "id": "#main/step_token",
                    "type": "File"
                },
                {
                    "id": "#main/thread_count",
                    "type": "long"
                }
            ],
            "outputs": [
                {
                    "id": "#main/token",
                    "type": "File",
                    "outputSource": "#main/sqlite_to_postgres/log"
                }
            ],
            "steps": [
                {
                    "id": "#main/emit_json",
                    "run": "#emit_json.cwl",
                    "in": [
                        {
                            "id": "#main/emit_json/string_keys",
                            "default": [
                                "cwl_workflow_git_hash",
                                "cwl_workflow_git_repo",
                                "cwl_workflow_rel_path",
                                "cwl_job_git_hash",
                                "cwl_job_git_repo",
                                "cwl_job_rel_path",
                                "hostname",
                                "host_ipaddress",
                                "host_macaddress",
                                "indexd_sqlite_uuid",
                                "status",
                                "job_uuid"
                            ]
                        },
                        {
                            "id": "#main/emit_json/string_values",
                            "source": [
                                "#main/cwl_workflow_git_hash",
                                "#main/cwl_workflow_git_repo",
                                "#main/cwl_workflow_rel_path",
                                "#main/cwl_job_git_hash",
                                "#main/cwl_job_git_repo",
                                "#main/cwl_job_rel_path",
                                "#main/hostname",
                                "#main/host_ipaddress",
                                "#main/host_macaddress",
                                "#main/indexd_sqlite_uuid",
                                "#main/status",
                                "#main/job_uuid"
                            ]
                        },
                        {
                            "id": "#main/emit_json/long_keys",
                            "default": [
                                "slurm_resource_cores",
                                "slurm_resource_disk_gigabytes",
                                "slurm_resource_mem_megabytes",
                                "thread_count"
                            ]
                        },
                        {
                            "id": "#main/emit_json/long_values",
                            "source": [
                                "#main/slurm_resource_cores",
                                "#main/slurm_resource_disk_gigabytes",
                                "#main/slurm_resource_mem_megabytes",
                                "#main/thread_count"
                            ]
                        },
                        {
                            "id": "#main/emit_json/float_keys",
                            "default": []
                        },
                        {
                            "id": "#main/emit_json/float_values",
                            "default": []
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/emit_json/output"
                        }
                    ]
                },
                {
                    "id": "#main/json_to_sqlite",
                    "run": "#json_to_sqlite.cwl",
                    "in": [
                        {
                            "id": "#main/json_to_sqlite/input_json",
                            "source": "#main/emit_json/output"
                        },
                        {
                            "id": "#main/json_to_sqlite/job_uuid",
                            "source": "#main/job_uuid"
                        },
                        {
                            "id": "#main/json_to_sqlite/table_name",
                            "source": "#main/status_table"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/json_to_sqlite/sqlite"
                        },
                        {
                            "id": "#main/json_to_sqlite/log"
                        }
                    ]
                },
                {
                    "id": "#main/sqlite_to_postgres",
                    "run": "#sqlite_to_postgres_hirate.cwl",
                    "in": [
                        {
                            "id": "#main/sqlite_to_postgres/postgres_creds_path",
                            "source": "#main/db_cred"
                        },
                        {
                            "id": "#main/sqlite_to_postgres/ini_section",
                            "source": "#main/db_cred_section"
                        },
                        {
                            "id": "#main/sqlite_to_postgres/source_sqlite_path",
                            "source": "#main/json_to_sqlite/sqlite"
                        },
                        {
                            "id": "#main/sqlite_to_postgres/job_uuid",
                            "source": "#main/job_uuid"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/sqlite_to_postgres/log"
                        }
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
